summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/kopeteawaydialog.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/libkopete/kopeteawaydialog.h')
-rw-r--r--kopete/libkopete/kopeteawaydialog.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kopete/libkopete/kopeteawaydialog.h b/kopete/libkopete/kopeteawaydialog.h
index 1c494e60..1ca75615 100644
--- a/kopete/libkopete/kopeteawaydialog.h
+++ b/kopete/libkopete/kopeteawaydialog.h
@@ -58,10 +58,10 @@ class KOPETE_EXPORT KopeteAwayDialog : public KDialogBase
public:
/**
* Constructor for the Away Dialog
* @param tqparent The object that owns this
* @param name Name for this object
*/
- KopeteAwayDialog( TQWidget *tqparent = 0, const char *name = 0 );
+ KopeteAwayDialog( TQWidget *parent = 0, const char *name = 0 );
/**
* Destructor
@@ -58,10 +58,10 @@ class KOPETE_EXPORT KopeteAwayDialog : public KDialogBase
/**
* Constructor for the Away Dialog
- * @param tqparent The object that owns this
+ * @param parent The object that owns this
* @param name Name for this object
*/